<?php
/*
 AUF plugin for GLPI
 Copyright (C) 2014 AUF -- www.auf.org
 */
if (!defined('GLPI_ROOT')) {
   die("Sorry. You can't access directly to this file");
}

class PluginAufComputer extends CommonDBTM {

   static function canCreate() {
      if (isset($_SESSION["glpi_plugin_auf_profile"])) {
         return ($_SESSION["glpi_plugin_auf_profile"]['auf'] == 'w');
      }
      return false;
   }

   static function canView() {
      if (isset($_SESSION["glpi_plugin_auf_profile"])) {
         return ($_SESSION["glpi_plugin_auf_profile"]['auf'] == 'w'
                 || $_SESSION["glpi_plugin_auf_profile"]['auf'] == 'r');
      }
      return false;
   }

   function createInfos($ID) {
      $this->add(array('id' => $ID));
   }

   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
      if ($item->getType() == 'Computer') {
         return "Infos AUF";
      }
      return '';
   }

   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
      if ($item->getType() == 'Computer') {
         $ID = $item->getID();
         $computer = new self();
         // si la machine n'existe pas dans la base, je l'ajoute
         if (!$computer->GetfromDB($ID)) {
            $computer->createInfos($ID);
         }
         $computer->showForm($ID);
      }
      return true;
   }

   function showForm($id, $options=array()) {
      $target = $this->getFormURL();
      if (isset($options['target'])) {
        $target = $options['target'];
      }

      if (!Session::haveRight("computer", "r")) {
         return false;
      }

      $canedit = Session::haveRight("computer", "w");
      $computer = new Computer();
      if ($id){
         $this->getFromDB($id);
         $computer->getFromDB($id);
      }

      echo "<form action='".$target."' method='post'>";
      echo "<table class='tab_cadre_fixe'>";
      echo "<tr><th colspan='4'>Infos AUF</th></tr>";

      echo "<tr class='tab_bg_1'>";
      echo "<td>Catégorie</td><td>";
      // $elements = getDataFromTable("glpi_plugin_auf_categories");
      $elements = array("0"=>"-----", "1"=>"Infrastructure", "2"=>"Poste interne", "3"=>"Poste public");
      Dropdown::showFromArray("auf_categories_id", $elements,
         array("value" => $this->fields["auf_categories_id"]));
      echo "</td>";
      echo "<td>Utilisation</td><td>";
      // $elements = getDataFromTable("glpi_plugin_auf_utilisations");
      $elements = array("0"=>"-----", "1"=>"Production", "2"=>"Test", "3"=>"Réserve (stock, mission, formation, …)");
      Dropdown::showFromArray("auf_utilisations_id", $elements,
         array("value" => $this->fields["auf_utilisations_id"]));
      echo "</td>";
      echo "</tr>";

      echo "<tr class='tab_bg_1'>";
      echo "<td>Machine virtuelle</td><td>";
      Dropdown::showYesNo('est_virtuel', $this->fields["est_virtuel"]);
      echo "</td>";
      echo "<td>Année d'acquisition</td><td>";
      echo "<input size='4' name='annee_acquisition' value='".$this->fields["annee_acquisition"]."' />";
      echo "</td>";
      echo "</tr>";

      if ($canedit) {
         echo "<tr class='tab_bg_1'>";
         echo "<td class='center' colspan='4'>";
         echo "<input type='hidden' name='id' value=$id>";
         echo "<input type='submit' name='update_computer' value='Mettre à jour' class='submit'>";
         echo "</td></tr>";
      }

      echo "</table>";
      Html::closeForm();
   }

}

?>
